<?php

namespace App\Http\Controllers;

use App\Helpers\JwtAuth;
use App\Evolucion;
use App\Tratamiento;
use Illuminate\Http\Request;

class EvolucionController extends Controller
{
    //INDICE
    public function index(Request $request)
    {
        // carga todos los vehículos con todos los datos del usuario
        $evoluciones = Evolucion::all();
        return response()->json(array(
            'evoluciones' => $evoluciones,
            'status' => 'success',
        ), 200);
    }

    // SHOW CONSULTA
    public function show($id)
    {
        $evolucion = Evolucion::find($id);
        if (is_object($evolucion)) {
            $evolucion = Evolucion::find($id);
            return response()->json(array(
                'evolucion' => $evolucion,
                'status' => 'success',
            ), 200);
        } else {
            return response()->json(array(
                'consulta' => 'La evolucion no existe',
                'status' => 'error',
            ), 200);
        }

    }

    //GUARDAR CONSULTA
    public function store(Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER DATOS POR POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // CONSEGUIR USUARIO IDENTIFICADO
            $user = $jwtAuth->checkToken($hash, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // GUARDAR CONSULTA

            $evolucion = new Evolucion();
            $evolucion->name = $params->name;
            $evolucion->descripcion = $params->descripcion;
            $evolucion->observaciones = $params->observaciones;
            $evolucion->paciente_id = $params->paciente_id;
            $evolucion->historia_id = $params->historia_id;

            $evolucion->save();

            $data = array(
                'evolucion' => $evolucion,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'evolucion' => 'Evolución incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ACTUALIZAR CONSULTA
    public function update($id, Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER PARÁMETROS POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // ACTUALIZAR CONSULTA
            unset($paramsArray['id']);
            unset($paramsArray['paciente_id']);
            unset($paramsArray['historia_id']);
            unset($paramsArray['created_at']);
            unset($paramsArray['user']);
            $evolucion = Evolucion::where('id', $id)->update($paramsArray);

            $data = array(
                'evolucion' => $params,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'evolucion' => 'Evolución incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ELIMINAR CONSULTA
    public function destroy($id, Request $request)
    {
        $hash = $request->header('Authorization', null);

        $jwtAuth = new JwtAuth();
        $checkToken = $jwtAuth->checkToken($hash);
        if ($checkToken) {
            //Tratamiento
            $tratamiento = Tratamiento::where('evolucion_id', $id);
            $tratamiento->delete();

            // Comprobar que existe el registro
            $evolucion = Evolucion::find($id);

            // Borrarlo
            $evolucion->delete();

            // Devolverlo
            $data = array(
                'evolucion' => $evolucion,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'evolucion' => 'Evolución incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

}
