<?php

namespace App\Http\Controllers;

use App\Historia;
use Illuminate\Http\Request;
use App\Http\Requests;
use App\Helpers\JwtAuth;
use App\Paciente;

class HistoriaController extends Controller
{
    //INDICE
    public function index(Request $request)
    {
        // carga todos los vehículos con todos los datos del usuario
        $historias = Historia::all();
        return response()->json(array(
            'historias' => $historias,
            'status' => 'success',
        ), 200);
    }

    // SHOW CONSULTA
    public function show($id)
    {
        $historia = Historia::find($id);
        if (is_object($historia)) {
            $historia = Historia::find($id);
            return response()->json(array(
                'historia' => $historia,
                'status' => 'success',
            ), 200);
        } else {
            return response()->json(array(
                'historia' => 'La historia no existe',
                'status' => 'error',
            ), 200);
        }

    }

    //GUARDAR CONSULTA
    public function store(Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER DATOS POR POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // CONSEGUIR USUARIO IDENTIFICADO
            $user = $jwtAuth->checkToken($hash, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // GUARDAR CONSULTA

            $historia = new Historia();
            $historia->paciente_id = $params->paciente_id;
            $historia->name = $params->name;
            $historia->antecedentes_familiares = $params->antecedentes_familiares;
            $historia->antecedentes_personales = $params->antecedentes_personales;
            $historia->exploracion = $params->exploracion;
            $historia->juicio_clinico = $params->juicio_clinico;
            $historia->observaciones = $params->observaciones;
            $historia->estado_paciente = $params->estado_paciente;
            $historia->diagnostico = $params->diagnostico;
            $historia->fecha_entrada = $params->fecha_entrada;

            $historia->save();

            $data = array(
                'historia' => $historia,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'message' => 'La historia es incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ACTUALIZAR CONSULTA
    public function update($id, Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER PARÁMETROS POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // ACTUALIZAR CONSULTA
            unset($paramsArray['id']);
            unset($paramsArray['paciente_id']);
            unset($paramsArray['created_at']);
            unset($paramsArray['user']);
            $historia = Historia::where('id', $id)->update($paramsArray);

            $data = array(
                'historia' => $params,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'historia' => 'Historia incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ELIMINAR CONSULTA
    public function destroy($id, Request $request)
    {
        $hash = $request->header('Authorization', null);

        $jwtAuth = new JwtAuth();
        $checkToken = $jwtAuth->checkToken($hash);
        if ($checkToken) {
            // Comprobar que existe el registro
            $historia = Historia::find($id);

            // Borrarlo
            $historia->delete();

            // Devolverlo
            $data = array(
                'historia' => $historia,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'historia' => 'Historia incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

}
