<?php

namespace App\Http\Controllers;

use App\Informe;
use Illuminate\Http\Request;
use App\Http\Requests;
use App\Helpers\JwtAuth;
use App\Paciente;

class InformeController extends Controller
{
    //INDICE
    public function index(Request $request)
    {
        // carga todos los vehículos con todos los datos del usuario
        $informes = Informe::all();
        return response()->json(array(
            'informes' => $informes,
            'status' => 'success',
        ), 200);
    }

    // SHOW CONSULTA
    public function show($id)
    {
        $informe = Informe::find($id);
        if (is_object($informe)) {
            $informe = Informe::find($id);
            return response()->json(array(
                'informe' => $informe,
                'status' => 'success',
            ), 200);
        } else {
            return response()->json(array(
                'informe' => 'El informe no existe',
                'status' => 'error',
            ), 200);
        }

    }

    //GUARDAR CONSULTA
    public function store(Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER DATOS POR POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // CONSEGUIR USUARIO IDENTIFICADO
            $user = $jwtAuth->checkToken($hash, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // GUARDAR CONSULTA

            $informe = new Informe();
            $informe->paciente_id = $params->paciente_id;
            $informe->name = $params->name;
            $informe->descripcion = $params->descripcion;
            $informe->observaciones = $params->observaciones;

            $informe->save();

            $data = array(
                'informe' => $informe,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'informe' => 'El informe es incorrecto',
                'status' => 'error',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ACTUALIZAR CONSULTA
    public function update($id, Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER PARÁMETROS POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // ACTUALIZAR CONSULTA
            unset($paramsArray['id']);
            unset($paramsArray['paciente_id']);
            unset($paramsArray['created_at']);
            unset($paramsArray['user']);
            $informe = Informe::where('id', $id)->update($paramsArray);

            $data = array(
                'informe' => $params,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'informe' => 'informe incorrecto',
                'status' => 'error',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ELIMINAR CONSULTA
    public function destroy($id, Request $request)
    {
        $hash = $request->header('Authorization', null);

        $jwtAuth = new JwtAuth();
        $checkToken = $jwtAuth->checkToken($hash);
        if ($checkToken) {
            // Comprobar que existe el registro
            $informe = Informe::find($id);

            // Borrarlo
            $informe->delete();

            // Devolverlo
            $data = array(
                'informe' => $informe,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'informe' => 'informe incorrecta',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

}
