<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Helpers\JwtAuth;
use App\Paciente;
use App\Tratamiento;
use App\Historia;
use App\Evolucion;
use App\Informe;

class PacienteController extends Controller
{
    //INDICE
    public function index(Request $request){
        // carga todos los pacientes con todos los datos del usuario
        $pacientes = Paciente::all();
        return response()->json(array(
            'pacientes' => $pacientes,
            'status' => 'success',
        ),200);
    }

    // MOSTRAR PACIENTE
    public function show($id){
        $paciente = Paciente::find($id);
        if(is_object($paciente)){
            $paciente = Paciente::find($id);
            return response()->json(array(
                'paciente' => $paciente,
                'status' => 'success',
            ),200);
        }else{
            return response()->json(array(
                'paciente' => 'El paciente no existe',
                'status' => 'error',
            ),200);
        }

    }

    //GUARDAR CONSULTA
    public function  store(Request $request){
        $hash = $request->header('Authorization',null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if($chekToken){
            // RECOGER DATOS POR POST
            $json = $request->input('json',null);
            $params = json_decode($json);
            $paramsArray = json_decode($json,true);

            // CONSEGUIR USUARIO IDENTIFICADO
            $user = $jwtAuth->checkToken($hash, true);

            // VALIDACION
            $request->merge($paramsArray);
            try{
                $validate = $this->validate($request,[
                    'name' => 'required'
                ]);
            }catch(\Illuminate\Validation\ValidationException $e){
                return $e->getReponse();

            }

            // GUARDAR CONSULTA

            $paciente = new Paciente();
            $paciente->consulta_id = $params->consulta_id;
            $paciente->name = $params->name;
            $paciente->surname = $params->surname;
            $paciente->email = $params->email;
            $paciente->telefono = $params->telefono;
            $paciente->documento = $params->documento;
            $paciente->domicilio = $params->domicilio;
            $paciente->provincia = $params->provincia;
            $paciente->ciudad = $params->ciudad;
            $paciente->codigopostal = $params->codigopostal;
            $paciente->nacimiento = $params->nacimiento;
            $paciente->genero = $params->genero;

            $paciente->save();

            $data = array(
                'paciente' => $paciente,
                'status' => 'success',
                'code' => 200
            );

        }else{

            $data = array(
                'message' => 'LOGIN INCORRECTO',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ACTUALIZAR PACIENTE
    public function update($id, Request $request){
        $hash = $request->header('Authorization',null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if($chekToken){
            // RECOGER PARÁMETROS POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // VALIDACION
            $request->merge($paramsArray);
            try{
                $validate = $this->validate($request,[
                    'name' => 'required'
                ]);
            }catch(\Illuminate\Validation\ValidationException $e){
                return $e->getReponse();

            }

            // ACTUALIZAR CONSULTA
            unset($paramsArray['id']);
            unset($paramsArray['consulta_id']);
            unset($paramsArray['created_at']);
            unset($paramsArray['user']);
            $paciente = Paciente::where('id', $id)->update($paramsArray);

            $data = array(
                'paciente' => $params,
                'status' => 'success',
                'code' => 200
            );

        }else{

            $data = array(
                'paciente' => 'LOGIN INCORRECTO',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ELIMINAR PACIENTE
    public function destroy($id, Request $request){
        $hash = $request->header('Authorization', null);

        $jwtAuth = new JwtAuth();
        $checkToken = $jwtAuth->checkToken($hash);
        if($checkToken){
            // Comprobar que existe el registro
            //Tratamiento
            $tratamiento = Tratamiento::where('paciente_id', $id);
            $tratamiento->delete();

            //Evolución
            $evolucion = Evolucion::where('paciente_id', $id);
            $evolucion->delete();


            //Historia
            $historia = Historia::where('paciente_id', $id);
            $historia->delete();


            // Informe
            $informe = Informe::where('paciente_id', $id);
            $informe->delete();

            $paciente = Paciente::find($id);

            // Borrarlo
            $paciente->delete();

            // Devolverlo
            $data = array(
                'paciente' => $paciente,
                'status' => 'success',
                'code' => 200
            );

        }else{

            $data = array(
                'paciente' => 'LOGIN INCORRECTO',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

}
