<?php

namespace App\Http\Controllers;

use App\Helpers\JwtAuth;
use App\Tratamiento;
use Illuminate\Http\Request;

class TratamientoController extends Controller
{
    //INDICE
    public function index(Request $request)
    {
        // carga todos los vehículos con todos los datos del usuario
        $tratamientos = Tratamiento::all();
        return response()->json(array(
            'tratamientos' => $tratamientos,
            'status' => 'success',
        ), 200);
    }

    // SHOW CONSULTA
    public function show($id)
    {
        $tratamiento = Tratamiento::find($id);
        if (is_object($tratamiento)) {
            $tratamiento = Tratamiento::find($id);
            return response()->json(array(
                'tratamiento' => $tratamiento,
                'status' => 'success',
            ), 200);
        } else {
            return response()->json(array(
                'tratamiento' => 'El tratamiento no existe',
                'status' => 'error',
            ), 200);
        }

    }

    //GUARDAR TRATAMIENTO
    public function store(Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER DATOS POR POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // CONSEGUIR USUARIO IDENTIFICADO
            $user = $jwtAuth->checkToken($hash, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // GUARDAR CONSULTA

            $tratamiento = new Tratamiento();
            $tratamiento->name = $params->name;
            $tratamiento->descripcion = $params->descripcion;
            $tratamiento->observaciones = $params->observaciones;
            $tratamiento->fecha = $params->fecha;
            $tratamiento->paciente_id = $params->paciente_id;
            $tratamiento->evolucion_id = $params->evolucion_id;

            $tratamiento->save();

            $data = array(
                'tratamiento' => $tratamiento,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'tratamiento' => 'Tratamiento erroneo',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ACTUALIZAR CONSULTA
    public function update($id, Request $request)
    {
        $hash = $request->header('Authorization', null);
        $jwtAuth = new JwtAuth();
        $chekToken = $jwtAuth->checkToken($hash);

        if ($chekToken) {
            // RECOGER PARÁMETROS POST
            $json = $request->input('json', null);
            $params = json_decode($json);
            $paramsArray = json_decode($json, true);

            // VALIDACION
            $request->merge($paramsArray);
            try {
                $validate = $this->validate($request, [
                    'name' => 'required'
                ]);
            } catch (\Illuminate\Validation\ValidationException $e) {
                return $e->getReponse();

            }

            // ACTUALIZAR CONSULTA
            unset($paramsArray['id']);
            unset($paramsArray['paciente_id']);
            unset($paramsArray['evolucion_id']);
            unset($paramsArray['created_at']);
            unset($paramsArray['user']);
            $tratamiento = Tratamiento::where('id', $id)->update($paramsArray);

            $data = array(
                'tratamiento' => $params,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'tratamiento' => 'Tratamiento erroneo',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

    // ELIMINAR CONSULTA
    public function destroy($id, Request $request)
    {
        $hash = $request->header('Authorization', null);

        $jwtAuth = new JwtAuth();
        $checkToken = $jwtAuth->checkToken($hash);
        if ($checkToken) {
            // Comprobar que existe el registro
            $tratamiento = Tratamiento::find($id);

            // Borrarlo
            $tratamiento->delete();

            // Devolverlo
            $data = array(
                'tratamiento' => $tratamiento,
                'status' => 'success',
                'code' => 200
            );

        } else {

            $data = array(
                'evolucion' => 'Tratamiento erroneo',
                'status' => 'success',
                'code' => 300
            );
        }

        return response()->json($data, 200);
    }

}
